==> haskell-simple-sendfile-0.2.28-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: simple-sendfile
version: 0.2.28
id: simple-sendfile-0.2.28-1IckMktzK9KJi2X7t6bypc
key: simple-sendfile-0.2.28-1IckMktzK9KJi2X7t6bypc
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.
category: Network
abi: 672ad8b47bb93f06bb8c5890dcc6f28c
exposed: True
exposed-modules:
    Network.Sendfile System.Linux.Sendfile
hidden-modules: Network.Sendfile.Types Network.Sendfile.Linux
import-dirs: /usr/lib/ghc-8.6.5/site-local/simple-sendfile-0.2.28
library-dirs: /usr/lib/ghc-8.6.5/site-local/simple-sendfile-0.2.28
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/simple-sendfile-0.2.28
hs-libraries: HSsimple-sendfile-0.2.28-1IckMktzK9KJi2X7t6bypc
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    network-2.8.0.0-g7zeLS1MQKFu6rNI1xGwt unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock
haddock-html: /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-simple-sendfile-0.2.28-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: simple-sendfile
version: 0.2.28
id: simple-sendfile-0.2.28-2uZdhQSfL5h4JSNgB9fHya
key: simple-sendfile-0.2.28-2uZdhQSfL5h4JSNgB9fHya
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.
category: Network
abi: 1203c4c45bd6e65339092cefa8458494
exposed: True
exposed-modules:
    Network.Sendfile System.Linux.Sendfile
hidden-modules: Network.Sendfile.Types Network.Sendfile.Linux
import-dirs: /usr/lib/ghc-8.6.5/site-local/simple-sendfile-0.2.28
library-dirs: /usr/lib/ghc-8.6.5/site-local/simple-sendfile-0.2.28
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/simple-sendfile-0.2.28
hs-libraries: HSsimple-sendfile-0.2.28-2uZdhQSfL5h4JSNgB9fHya
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    network-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock
haddock-html: /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
